#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = u"Rafał Selewońko <rafal@selewonko.com>"

from django.contrib import admin
from super_inlines.admin import SuperInlineModelAdmin, SuperModelAdmin
from django.contrib.contenttypes.admin import GenericStackedInline

from django.utils.translation import ugettext_lazy as _
from filebrowser.settings import ADMIN_THUMBNAIL


class SectionAdminMixin(object):

    sortable_field_name = 'order'
    show_change_link = True

    list_display = ('__str__', 'image_thumbnail')
    list_filter = ()
    search_fields = ('title', 'description', 'slug')
    date_hierarchy = 'created'
    save_as = True
    save_on_top = True
    actions_on_top = True
    actions_on_bottom = True

    def image_thumbnail(self, obj):
        if obj.image and obj.image.filetype == "Image":
            url = obj.image.version_generate(ADMIN_THUMBNAIL).url
            return '<img src="{}" />'.format(url)
        else:
            return ""
    image_thumbnail.allow_tags = True
    image_thumbnail.short_description = "Thumbnail"

    extra = 0
    sortable_field_name = 'order'
    show_change_link = True

    related_lookup_fields = {
        'generic': [['content_type', 'object_id']],

    }

    fieldsets = ((
        _("Page"), {
            'fields': (
                ('title', ),
                ('description', ),
                ('image', ),
                ('content_type', 'object_id'),
                ('options', ),
                ('order', ),
                ('template_name', ),
            )
        }), (
        _("Activation"), {
            'classes': ('grp-collapse grp-closed',),
            'fields': (
                ('status', ),
                ('activate_date', 'deactivate_date'),
            )
        }))


class SectionInlineAdminBase(SectionAdminMixin, SuperInlineModelAdmin,
                             GenericStackedInline):
    ct_field = "section_content_type"
    ct_fk_field = "section_object_id"


class SectionAdminBase(SectionAdminMixin, SuperModelAdmin, admin.ModelAdmin):
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

u"""
django-sections
"""
__author__ = u"Rafał Selewońko <rafal@selewonko.com>"
__version__ = '0.1'
default_app_config = 'gipsy.sections.apps.GipsySections'



#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = u"Rafał Selewońko <rafal@selewonko.com>"

from django.conf import settings
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db import models
from django.utils import six
from django.utils.translation import ugettext_lazy as _
from django_extensions.db.models import (ActivatorModel, TimeStampedModel,
                                         TitleSlugDescriptionModel)
from filebrowser.fields import FileBrowseField

from optionsfield import OptionsField


class UserStampedModel(models.Model):

    created_by = models.CharField(
        blank=True,
        editable=False,
        max_length=128,
        null=True,
        verbose_name=_('Created by'))

    modified_by = models.CharField(
        blank=True,
        editable=False,
        max_length=128,
        null=True,
        verbose_name=_('Modified by'))

    class Meta:
        abstract = True

    def save(self, by=None, *args, **kwargs):
        if by:
            if self.pk is None:
                self.created_by = by
            else:
                self.modified_by = by

        super(UserStampedModel, self).save(*args, **kwargs)


class SectionBase(UserStampedModel, ActivatorModel, TitleSlugDescriptionModel,
                  TimeStampedModel):

    order = models.PositiveIntegerField(
        default=0,
        verbose_name=_(u"order"))

    image = FileBrowseField(
        blank=True,
        directory="partners/images/",
        extensions=('.jpg', '.png', '.jpeg', '.gif'),
        max_length=255,
        null=True,
        verbose_name="Image")

    TEMPLATE_NAME_CHOICES = getattr(
        settings, 'GIPSY_SECTIONS_SECTION_TEMPLATE_NAME_CHOICES')

    template_name = models.CharField(
        blank=True,
        null=True,
        # choices=TEMPLATE_NAME_CHOICES,
        max_length=255,
        verbose_name=_(u"template"))

    OPTIONS_TYPES = six.string_types

    options = OptionsField(types=OPTIONS_TYPES, verbose_name=_(u"options"))

    # parent section or other object to which this section is connect to
    section_content_type = models.ForeignKey(ContentType, null=True, blank=True, related_name='sections')
    section_object_id = models.PositiveIntegerField(null=True, blank=True)
    section_content_object = GenericForeignKey('section_content_type', 'section_object_id')

    # object embedded in section
    content_type = models.ForeignKey(ContentType, null=True, blank=True)
    object_id = models.PositiveIntegerField(null=True, blank=True)
    content_object = GenericForeignKey('content_type', 'object_id')

    class Meta:
        abstract = True
        verbose_name = _(u"section")
        verbose_name_plural = _(u"sections")
        ordering = ('order',)
        get_latest_by = 'created'

    def __str__(self):
        return self.title

    def get_description(self):
        if self.description:
            description = self.description
        elif self.content_object and self.content_object.description:
            description = self.content_object.description
        else:
            description = None
        return description



#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = u"Rafał Selewońko <rafal@selewonko.com>"

from django.contrib.contenttypes.models import ContentType
from django_extensions.db.models import (ActivatorModelManager,
                                         ActivatorQuerySet)


class SectionQuerySet(ActivatorQuerySet):
    pass


class SectionManager(ActivatorModelManager):

    def get_queryset(self):
        return SectionQuerySet(model=self.model, using=self._db)


def SectionsManager():
    "Related sections manager"
    @property
    def wrap(self):
        content_type = ContentType.objects.get_for_model(self.__class__)
        from gipsy.sections.models import Section
        return Section.objects.filter(
            section_content_type=content_type,
            section_object_id=self.id)
    return wrap



from django import forms

from optionsfield.fields import OptionsWidget


class SectionAdminFormBase(forms.ModelForm):

    template_name = forms.TypedChoiceField(required=False)

    def __init__(self, *args, **kwargs):
        super(SectionAdminFormBase, self).__init__(*args, **kwargs)
        choices = ((None, '------'), ) + self._meta.model.TEMPLATE_NAME_CHOICES
        self.fields['template_name'].choices = choices
        try:
            self.fields['options'].widget = OptionsWidget()
        except KeyError:
            pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = u"Rafał Selewońko <rafal@selewonko.com>"


from gipsy.sections.models_base import SectionBase
from gipsy.sections.managers import SectionManager, SectionsManager


class Section(SectionBase):

    objects = SectionManager()
    sections = SectionsManager()



from gipsy.sections.forms_base import SectionAdminFormBase
from gipsy.sections.models import Section


class SectionAdminForm(SectionAdminFormBase):

    class Meta:
        model = Section
        fields = '__all__'



#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = u"Rafał Selewońko <rafal@selewonko.com>"

from django.contrib import admin

from gipsy.sections.admin_base import SectionAdminBase, SectionInlineAdminBase
from gipsy.sections.forms import SectionAdminForm
from gipsy.sections.models import Section


class SectionInlineInlineAdmin(SectionInlineAdminBase):
    model = Section
    form = SectionAdminForm


class SectionInlineAdmin(SectionInlineAdminBase):
    model = Section
    form = SectionAdminForm
    inlines = [SectionInlineInlineAdmin]


class SectionAdmin(SectionAdminBase):
    form = SectionAdminForm
    inlines = [SectionInlineAdmin]


admin.site.register(Section, SectionAdmin)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.utils.timezone
import optionsfield.fields
import filebrowser.fields
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='Section',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', django_extensions.db.fields.CreationDateTimeField(default=django.utils.timezone.now, verbose_name='created', editable=False, blank=True)),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(default=django.utils.timezone.now, verbose_name='modified', editable=False, blank=True)),
                ('title', models.CharField(max_length=255, verbose_name='title')),
                ('description', models.TextField(null=True, verbose_name='description', blank=True)),
                ('slug', django_extensions.db.fields.AutoSlugField(populate_from=b'title', verbose_name='slug', editable=False, blank=True)),
                ('status', models.IntegerField(default=1, verbose_name='status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('activate_date', models.DateTimeField(help_text='keep empty for an immediate activation', null=True, blank=True)),
                ('deactivate_date', models.DateTimeField(help_text='keep empty for indefinite activation', null=True, blank=True)),
                ('created_by', models.CharField(verbose_name='Created by', max_length=128, null=True, editable=False, blank=True)),
                ('modified_by', models.CharField(verbose_name='Modified by', max_length=128, null=True, editable=False, blank=True)),
                ('order', models.PositiveIntegerField(default=0, verbose_name='order')),
                ('image', filebrowser.fields.FileBrowseField(max_length=255, null=True, verbose_name=b'Image', blank=True)),
                ('template_name', models.CharField(max_length=255, null=True, verbose_name='template', blank=True)),
                ('options', optionsfield.fields.OptionsField(verbose_name='options', types=(unicode, str))),
                ('section_object_id', models.PositiveIntegerField(null=True, blank=True)),
                ('object_id', models.PositiveIntegerField(null=True, blank=True)),
                ('content_type', models.ForeignKey(blank=True, to='contenttypes.ContentType', null=True)),
                ('section_content_type', models.ForeignKey(related_name='sections', blank=True, to='contenttypes.ContentType', null=True)),
            ],
            options={
                'ordering': ('order',),
                'get_latest_by': 'created',
                'verbose_name': 'section',
                'verbose_name_plural': 'sections',
            },
        ),
    ]



#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = u"Rafał Selewońko <rafal@selewonko.com>"

import os

from pip.req import parse_requirements
from setuptools import setup, find_packages

# allow setup.py to be run from any path and open files
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))


def get_requirements(filename):
    install_requires = []
    dependency_links = []
    for r in parse_requirements(filename, session=False):
        if hasattr(r, 'link') and r.link and r.link.url:
            r.req.specs = [('<=', '99.99')]
            dependency_links.append(r.link.url+'-99.99')
        install_requires.append(str(r.req))
    return install_requires, dependency_links

install_requires, dependency_links = get_requirements('requirements.txt')
tests_require, dependency_links2 = get_requirements('requirements/test.txt')
dependency_links = list(set(dependency_links + dependency_links2))

version = '0.1.5'
description = 'Gipsy Sections'


setup(
    name='gipsy-sections',
    version=version,
    author=u'Rafał Selewońko',
    author_email='rafal@selewonko.com',
    description=description,
    url='http://github.com/revsquare/gipsy-sections',
    packages=find_packages(),
    namespace_packages=['gipsy'],
    include_package_data=True,
    license='MIT',
    long_description=open('README.rst').read(),
    classifiers=[
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Internet :: WWW/HTTP',
    ],
    install_requires=install_requires,
    dependency_links=dependency_links,
    tests_require=tests_require,
)
